clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"



*
* Least Traded Exercise - KORUS
*

use "`in_dir'\KORUS", replace

gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100

**import=1 corresponds to Korea importing from US
gen import = 1 if importer == 410
replace import = 0 if exporter == 410


collapse (sum) value, by(code year import)


save "`temp_dir'\temp", replace

*
* concord the KORUS data
*


use "`in_dir'\SITC5_to_ISIC3",replace

rename sitc code

merge 1:m code using "`temp_dir'\temp"

*merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
keep if _merge == 3
drop _merge

***311 and 312 are the same, so put both in 311
replace isic2 = 311 if isic2 == 312

*
* Reshape the data
*


gen pair = string(import,"%03.0f") + "-" + string(code,"%05.0f")

reshape wide value, i(pair) j(year)

gen pre_val = value2005


egen pre_val_avg = rowmean(value2005 value2006 value2007)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(import)
rename pre_val pre_total

merge 1:m import using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort import pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by import, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.


rename code sitc

keep import pre_val least sitc isic2

save "`temp_dir'\temp", replace


gen least_val_pre = least*pre_val

gen notleast = abs(1-least)

gen notleast_val_pre = notleast*pre_val


collapse (sum) pre_val least_val_* notleast_val_* least notleast, by(import isic2)

save "`temp_dir'\temp", replace


gen perleast = least_val_pre/(least_val_pre+notleast_val_pre)

gen importer = 410 if import == 1
replace importer = 842 if import == 0

gen exporter = 410 if import == 0
replace exporter = 842 if import == 1

label define imports 1 "Imports" 0 "Exports"
label values import imports

**predicted growth in j = a + b * s_j
gen predgrowth = -10.95 + 197.66 * perleast if import == 1
replace predgrowth =  -3.63 + 160.10 * perleast if import == 0

save "`out_dir'\korus_ISIC_RESULTS", replace


***save the tables
cd "`out_dir'"


use "`out_dir'\korus_ISIC_RESULTS", replace
format predgrowth %9.1f
format perleast %9.2f
keep if import == 0
gen code = isic2
order isic2 code predgrowth perleast
keep isic2 code predgrowth perleast
rename isic2 sector
sort code
outsheet using "`out_dir'\tables\Table 2 KORUS_ISIC Kor Exports.txt", names replace


use "`out_dir'\korus_ISIC_RESULTS", replace
format predgrowth %9.1f
format perleast %9.2f
keep if import == 1
gen code = isic2
order isic2 code predgrowth perleast
keep isic2 code predgrowth perleast
rename isic2 sector
sort code
outsheet using "`out_dir'\tables\Table 2 KORUS_ISIC Kor Imports.txt", names replace

